## candid-python: A [Candid Health](https://joincandidhealth.com) Python client
[![PyPI](https://img.shields.io/pypi/v/candidhealth)](https://pypi.org/project/candidhealth/)
[![fern shield](https://img.shields.io/badge/%F0%9F%8C%BF-SDK%20generated%20by%20Fern-brightgreen)](https://buildwithfern.com/?utm_source=candidhealth/candid-python/readme)

### Installation
```bash
pip install candidhealth   # or poetry install, etc.
```
